@@ -13,6 +13,7 @@ sub new {
   );
 
   if ($args{suggests}) {
+    $context{recommends} = CPAN::Meta::Requirements->new;
     $context{suggests} = CPAN::Meta::Requirements->new;
   }
   for my $type (qw/use no method keyword/) {
@@ -43,23 +44,25 @@ sub register_method {
 }
 
 sub requires { shift->{requires} }
+sub recommends { shift->_optional('recommends') }
+sub suggests { shift->_optional('suggests') }
 
-sub suggests {
-  my $self = shift;
-  my $suggests = $self->{suggests} or return;
+sub _optional {
+  my ($self, $key) = @_;
+  my $optional = $self->{$key} or return;
 
-  # no need to suggest what are listed as requires
+  # no need to recommend/suggest what are listed as requires
   if (my $requires = $self->{requires}) {
-    my $hash = $suggests->as_string_hash;
+    my $hash = $optional->as_string_hash;
     for my $module (keys %$hash) {
       if (defined $requires->requirements_for_module($module) and
           $requires->accepts_module($module, $hash->{$module})
       ) {
-        $suggests->clear_requirement($module);
+        $optional->clear_requirement($module);
       }
     }
   }
-  $suggests;
+  $optional;
 }
 
 sub add {
@@ -71,6 +74,15 @@ sub add {
   $CMR->add_minimum($module, "$version");
 }
 
+sub add_recommendation {
+  my ($self, $module, $version) = @_;
+  return unless is_module_name($module);
+
+  my $CMR = $self->_object('recommends') or return;
+  $version = 0 unless defined $version;
+  $CMR->add_minimum($module, "$version");
+}
+
 sub has_added {
   my ($self, $module) = @_;
   return unless is_module_name($module);
@@ -79,37 +91,20 @@ sub has_added {
   defined $CMR->requirements_for_module($module) ? 1 : 0;
 }
 
+sub has_added_recommendation {
+  my ($self, $module) = @_;
+  return unless is_module_name($module);
+
+  my $CMR = $self->_object('recommends') or return;
+  defined $CMR->requirements_for_module($module) ? 1 : 0;
+}
+
 sub _object {
-  my $self = shift;
-  my $key = $self->is_in_eval ? 'suggests' : 'requires';
+  my ($self, $allow_recommends) = @_;
+  my $key = $self->{eval} ? 'suggests' : ($allow_recommends && $self->{cond}) ? 'recommends' : 'requires';
   $self->{$key} or return;
 }
 
-sub skips_eval {
-  my $self = shift;
-  return $self->{suggests} ? 0 : 1;
-}
-
-sub is_in_eval {
-  my $self = shift;
-
-  exists $self->{eval} ? 1 : 0;
-}
-
-sub enter_eval {
-  my ($self, $depth) = @_;
-  push @{$self->{eval} ||= []}, $depth;
-}
-
-sub exit_eval_if_match {
-  my ($self, $depth) = @_;
-  return unless exists $self->{eval};
-  if ($self->{eval}[-1] == $depth) {
-    pop @{$self->{eval}};
-    delete $self->{eval} if !@{$self->{eval}};
-  }
-}
-
 sub has_callbacks {
   my ($self, $type) = @_;
   exists $self->{$type};
@@ -155,20 +150,6 @@ with different versions as many times as you wish. The actual
 minimum version for the module is calculated inside
 (by L<CPAN::Meta::Requirements>).
 
-=head2 enter_eval, exit_eval_if_match, is_in_eval, skips_eval
-
-  $c->enter_eval($tokens->block_depth);
-  if (!$c->skips_eval or !$c->is_in_eval) {
-    ... # do something
-  }
-  $c->exit_eval_if_match($tokens->block_depth + 1);
-
-If you find a token for C<eval> or its equivalents,
-call C<enter_eval> to tell the context object from which block the
-eval has started. (You can pass a negative value when a string
-C<eval> is found). You can use C<exit_eval_if_match> to
-end C<eval> when you get out of the block.
-
 =head2 register_keyword, remove_keyword, register_method
 
   $c->register_keyword(
