@@ -10,12 +10,19 @@ use File::Temp qw/tempdir/;
 use File::Basename qw/dirname/;
 use File::Path qw/mkpath rmtree/;
 
-our @EXPORT = qw/test used test_app test_file/;
+our @EXPORT = qw/test todo_test used test_app test_file/;
 our $EVAL;
 our $PARSERS;
 
+sub todo_test {
+  SKIP: {
+    local $TODO = "FIXME";
+    test(@_);
+  }
+}
+
 sub test {
-  my ($description, $string, $expected_requires, $expected_suggests) = @_;
+  my ($description, $string, $expected_requires, $expected_suggests, $expected_recommends) = @_;
   subtest $description => sub {
     my $scanner = Perl::PrereqScanner::NotQuiteLite->new(
       parsers => $PARSERS || [qw/:bundled/],
@@ -32,6 +39,12 @@ sub test {
       is_deeply $suggests_hash => $expected_suggests, "suggests ok";
       note explain $suggests_hash;
     }
+    if ($expected_recommends) {
+      my $recommends = $context->recommends;
+      my $recommends_hash = $recommends ? $recommends->as_string_hash : {};
+      is_deeply $recommends_hash => $expected_recommends, "recommends ok";
+      note explain $recommends_hash;
+    }
     if ($EVAL) {
       eval "no strict; $string";
       ok !$@, "no eval error";
